@@ -52,6 +52,12 @@ func WithRuntimePath(path string) ConmonOption {
 	}
 }
 
+func WithLogLevel(path string) ConmonOption {
+	return func(ci *ConmonInstance) error {
+		return ci.addArgs("--log-level", path)
+	}
+}
+
 func WithLogDriver(driver, path string) ConmonOption {
 	return func(ci *ConmonInstance) error {
 		fullDriver := path
@@ -62,6 +68,12 @@ func WithLogDriver(driver, path string) ConmonOption {
 	}
 }
 
+func WithLogPath(path string) ConmonOption {
+	return func(ci *ConmonInstance) error {
+		return ci.addArgs("--log-path", path)
+	}
+}
+
 func (ci *ConmonInstance) addArgs(args ...string) error {
 	ci.args = append(ci.args, args...)
 	return nil
